---
title: marvin
---

# `marvin`

## Submodules
- [`agents`](marvin-agents)
- [`cli`](marvin-cli)
- [`database`](marvin-database)
- [`defaults`](marvin-defaults)
- [`engine`](marvin-engine)
- [`fns`](marvin-fns)
- [`handlers`](marvin-handlers)
- [`instructions`](marvin-instructions)
- [`memory`](marvin-memory)
- [`prompts`](marvin-prompts)
- [`settings`](marvin-settings)
- [`tasks`](marvin-tasks)
- [`thread`](marvin-thread)
- [`tools`](marvin-tools)
- [`utilities`](marvin-utilities)
